==> auto_entitylabel-8.x-3.1.zip: auto_entitylabel/README.md <==
# Automatic Entity Label

"Automatic Entity Label" is a small and efficient module that allows
hiding of entity label fields. To prevent empty labels it can be 
configured to generate the label automatically by a given pattern.
This can be used on any entity type, including e.g. for node 
titles, comment subjects, taxonomy term names and profile2 labels.

For a full description of the module, visit the 
[project page](https://www.drupal.org/project/auto_entitylabel).

Submit bug reports and feature suggestions, or track changes in the
[Issue queue](https://www.drupal.org/project/issues/auto_entitylabel). 


## Table of contents

- Requirements
- Recommended modules
- Installation
- Configuration
- Maintainers


## Requirements

This module requires no modules outside of Drupal core.


## Recommended modules

- [Token](http://drupal.org/project/token): For token replacement help.


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-modules).


## Configuration

1. After installing, go to: _/admin/structure/types_.
2. In the drop down select: "Manage automatic entity labels".
3. Select which option for client and create a pattern.


## Maintainers

Current maintainers:
- Benedikt Forchhammer [@bforchhammer](https://www.drupal.org/u/bforchhammer)
- Colan Schwartz [@colan](https://www.drupal.org/u/colan)
- Jakob Perry [@japerry](https://www.drupal.org/u/japerry)
- renatog [@renatog](https://www.drupal.org/u/renatog)
- dqd [@dqd](https://www.drupal.org/u/dqd)
- Pravin raj [@Pravin Ajaaz](https://www.drupal.org/u/pravin-ajaaz)
- Purushotam Rai [@purushotam.rai](https://www.drupal.org/u/purushotamrai)
- Vladimir Roudakov [@VladimirAus](https://www.drupal.org/u/vladimiraus)

==> auto_entitylabel-8.x-3.2.zip: auto_entitylabel/README.md <==
# Automatic Entity Label

"Automatic Entity Label" is a small and efficient module that allows
hiding of entity label fields. To prevent empty labels it can be 
configured to generate the label automatically by a given pattern.
This can be used on any entity type, including e.g. for node 
titles, comment subjects, taxonomy term names and profile2 labels.

For a full description of the module, visit the 
[project page](https://www.drupal.org/project/auto_entitylabel).

Submit bug reports and feature suggestions, or track changes in the
[Issue queue](https://www.drupal.org/project/issues/auto_entitylabel). 


## Table of contents

- Requirements
- Recommended modules
- Installation
- Configuration
- Maintainers


## Requirements

This module requires no modules outside of Drupal core.


## Recommended modules

- [Token](http://drupal.org/project/token): For token replacement help.


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-modules).


## Configuration

1. After installing, go to: _/admin/structure/types_.
2. In the drop down select: "Manage automatic entity labels".
3. Select which option for client and create a pattern.


## Maintainers
[//]: # cSpell:disable
[//]: # Do not add maintainers to cspell-project-words file

Current maintainers:
- Benedikt Forchhammer [@bforchhammer](https://www.drupal.org/u/bforchhammer)
- Colan Schwartz [@colan](https://www.drupal.org/u/colan)
- Jakob Perry [@japerry](https://www.drupal.org/u/japerry)
- renatog [@renatog](https://www.drupal.org/u/renatog)
- dqd [@dqd](https://www.drupal.org/u/dqd)
- Pravin raj [@Pravin Ajaaz](https://www.drupal.org/u/pravin-ajaaz)
- Purushotam Rai [@purushotam.rai](https://www.drupal.org/u/purushotamrai)
- Vladimir Roudakov [@VladimirAus](https://www.drupal.org/u/vladimiraus)
- Martin Anderson-Clutz [@mandclu](https://www.drupal.org/u/mandclu)
